==> yexpert-js-0.0.98.tgz: package/postinstall/www/yexpert/app.js <==
/*

!----------------------------------------------------------------------------!
!                                                                            !
! Yexpert : (your) Système Expert sous Mumps GT.M et GNU/Linux               !
! Copyright (C) 2001-2015 by Hamid LOUAKED (HL).                             !
!                                                                            !
!----------------------------------------------------------------------------!

*/

var EWD = require('ewd-client').EWD;
var io = require('socket.io-client')
var jQuery = require('jquery');
window.$ = window.jQuery = jQuery;
require('bootstrap');
var login = require('yexpert-login/client/login');
var toastr = require('toastr');

$(document).ready(function() {
  EWD.on('ewd-registered', function() {
    EWD.log = true;
    var params = {
      service: 'yexpert-login',
      name: 'login.html',
      targetId: 'loginPanel'
    };
    EWD.getFragment(params, function() {
      login(EWD, function(responseObj) {
        console.log('*** logged in!');
        $('#welcomePanel').text(responseObj.message.greeting);
        toastr.success(responseObj.message.greeting);
      });
    });

  });

  EWD.on('error', function(responseObj) {
    // automatically display all returned errors using toastr
    var error = responseObj.message.error || responseObj.message;
    toastr.error(error);
  });

  /*
     alternative using an emitted event

  EWD.on('loggedIn', function(responseObj) {
    console.log('*** logged in!');
    $('#welcomePanel').text(responseObj.message.greeting);
    toastr.success(responseObj.message.greeting);
  });

  */

  EWD.start('yexpert', jQuery, io);
});

==> yexpert-js-0.0.106.tgz: package/postinstall/www/yexpert/app.js <==
/*

!----------------------------------------------------------------------------!
!                                                                            !
! Yexpert : (your) Système Expert sous Mumps GT.M et GNU/Linux               !
! Copyright (C) 2001-2015 by Hamid LOUAKED (HL).                             !
!                                                                            !
!----------------------------------------------------------------------------!

*/

var EWD = require('ewd-client').EWD;
var io = require('socket.io-client')
var jQuery = require('jquery');
window.$ = window.jQuery = jQuery;
require('bootstrap');
var login = require('yexpert-js/client/login');
var toastr = require('toastr');

$(document).ready(function() {
  EWD.on('ewd-registered', function() {
    EWD.log = true;
    var params = {
      service: 'yexpert-js',
      name: 'login.html',
      targetId: 'loginPanel'
    };
    EWD.getFragment(params, function() {
      login(EWD, function(responseObj) {
        console.log('*** logged in!');
        $('#welcomePanel').text(responseObj.message.greeting);
        toastr.success(responseObj.message.greeting);
      });
    });

  });

  EWD.on('error', function(responseObj) {
    // automatically display all returned errors using toastr
    var error = responseObj.message.error || responseObj.message;
    toastr.error(error);
  });

  /*
     alternative using an emitted event

  EWD.on('loggedIn', function(responseObj) {
    console.log('*** logged in!');
    $('#welcomePanel').text(responseObj.message.greeting);
    toastr.success(responseObj.message.greeting);
  });

  */

  EWD.start('yexpert', jQuery, io);
});
